@@ -173,6 +173,22 @@ impl ops::Mul<i64> for &AmountView {
     }
 }
 
+impl ops::Mul<i32> for AmountView {
+    type Output = Self;
+
+    fn mul(self, other: i32) -> Self::Output {
+        AmountView::fractions(self.value * other as i64)
+    }
+}
+
+impl ops::Mul<i32> for &AmountView {
+    type Output = AmountView;
+
+    fn mul(self, other: i32) -> Self::Output {
+        AmountView::fractions(self.value * other as i64)
+    }
+}
+
 impl ops::Mul<u8> for AmountView {
     type Output = Self;
 
@@ -189,6 +205,42 @@ impl ops::Mul<u8> for &AmountView {
     }
 }
 
+impl ops::Mul<f32> for AmountView {
+    type Output = Self;
+
+    fn mul(self, other: f32) -> Self::Output {
+        let fac = (other * 100.).round() as i64;
+        AmountView::fractions(self.value * fac / 100)
+    }
+}
+
+impl ops::Mul<f32> for &AmountView {
+    type Output = AmountView;
+
+    fn mul(self, other: f32) -> Self::Output {
+        let fac = (other * 100.).round() as i64;
+        AmountView::fractions(self.value * fac / 100)
+    }
+}
+
+impl ops::Mul<f64> for AmountView {
+    type Output = Self;
+
+    fn mul(self, other: f64) -> Self::Output {
+        let fac = (other * 100.).round() as i64;
+        AmountView::fractions(self.value * fac / 100)
+    }
+}
+
+impl ops::Mul<f64> for &AmountView {
+    type Output = AmountView;
+
+    fn mul(self, other: f64) -> Self::Output {
+        let fac = (other * 100.).round() as i64;
+        AmountView::fractions(self.value * fac / 100)
+    }
+}
+
 // Division
 
 impl ops::Div<i64> for AmountView {
@@ -266,6 +318,14 @@ impl cmp::PartialOrd for AmountView {
 mod tests {
     use super::*;
 
+    #[test]
+    fn test_float_mul() {
+        assert_eq!(
+            AmountView::fractions(4000_00) * 0.9,
+            AmountView::fractions(3600_00)
+        );
+    }
+
     #[test]
     fn test_formatting() {
         assert_eq!(
